import asyncio
import time

from python_aternos import AternosServer, Client, Streams
from typing import Tuple, Dict, Any, List

from rich.console import Console
from rich.live import Live
from rich.prompt import Prompt, IntPrompt
from rich.table import Table


console = Console()

list_players = []


async def get_server(aternos: Client) -> AternosServer:
    _show_servers(aternos.list_servers())
    server_choose = IntPrompt.ask("Select server", default=0)
    server: AternosServer = aternos.list_servers()[server_choose]
    return server


def connect() -> Client:
    try:
        aternos = Client.restore_session()
    except FileNotFoundError:
        user = Prompt.ask("Enter the login")
        password = Prompt.ask("Enter the password", password=True)
        aternos = Client.from_credentials(user, password)
        aternos.save_session()
    return aternos


async def connect(server: AternosServer) -> None:
    with Live(_show_players([]), refresh_per_second=4) as live:
        await _socket_connect(server, live)


async def _socket_connect(server: AternosServer, live: Live) -> None:
    socket = server.wss()

    @socket.wssreceiver(Streams.status, ('Server 1',))
    async def state(
            msg: Dict[Any, Any],
            args: Tuple[str]) -> None:
        server._info = msg
        # console.print(args)
        # _show_server(server)
        # _show_players(server.players_list)
        live.update(_show_players(server.players_list))

    await socket.connect()
    await asyncio.create_task(_loop())


def _show_servers(servers: List[AternosServer]) -> None:
    table = Table("#", "Server", "Version", "Status")
    for index, server in enumerate(servers):
        table.add_row(str(index), server.address, server.version, server.status)
    console.print(table)


def _show_server(server: AternosServer) -> None:
    table = Table("#", "Server", "Version", "Status")
    table.add_row("0", server.address, server.version, server.status)
    console.print(table)


def _show_players(players: List[str]) -> None:
    table = Table("Players online")
    for player in players:
        table.add_row(player)
    console.print(table)


async def _loop() -> None:
    while True:
        await asyncio.Future()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['aternos']

package_data = \
{'': ['*']}

install_requires = \
['asyncio>=3.4.3,<4.0.0',
 'python-aternos>=2.1.3,<3.0.0',
 'typer[all]>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['aternos = aternos.main:app']}

setup_kwargs = {
    'name': 'aternos-client',
    'version': '0.1.1',
    'description': 'A simple client to connect on Aternos server',
    'long_description': "# Hi mineguys  👋\n\n\n## 🛠️ Install     \n```bash\npip install aternos\n```\n\n## 🧑🏻\u200d💻 Usage\n```js\naternos start\naternos stop\naternos info\n```\n\n## Contributing\n\nIf you want participate project\n```bash\npoetry install\n```\n\nDepot coming soon\nif you don't have [poetry](https://python-poetry.org/docs/#installation)\n        ",
    'author': 'qrillet',
    'author_email': 'quentin.rillet@externe.covage.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.11,<4.0',
}


setup(**setup_kwargs)



import asyncio
import typer
from rich.console import Console
from rich.live import Live
from rich.table import Table

from aternos.server import connect, get_server

console = Console()
app = typer.Typer()
aternos = connect()


async def _main_start() -> None:
    server = await get_server(aternos)

    if server.status == 'offline':
        console.print(':rocket: Starting server...')
        server.start()
    else:
        console.print('Server is already running :thumbs_up:')

    await connect(server)


async def _main_info() -> None:
    server = await get_server(aternos)
    if server.status != 'offline':
        await connect(server)
    else:
        console.print('Server is offline :rocket:')


async def _main_stop() -> None:
    server = await get_server(aternos)
    server.stop()


@app.command()
def start() -> None:
    asyncio.run(_main_start())


@app.command()
def stop() -> None:
    asyncio.run(_main_stop())


@app.command()
def info() -> None:
    asyncio.run(_main_info())


def tt():
    table = Table("YOLO")
    table.add_row("ouiiii")
    return table


async def _yolo() -> None:
    with Live(tt()) as live_t:
        live_t.update(tt())


@app.command()
def live() -> None:
    asyncio.run(_yolo())
